/*
    SPDX-FileCopyrightText: 2010 Paulo Romulo Alves Barros <paulo.romulo@kdemail.net>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#define UDEV_FOUND 1

#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_MNTTAB_H 0
#define HAVE_SYS_MOUNT_H 1

#define HAVE_GETMNTINFO 0

#define HAVE_LIBMOUNT 1

#define GETMNTINFO_USES_STATVFS 0
